==> mastapy-14.0.0b1.tar.gz: mastapy-14.0.0b1/mastapy/_private/_internal/implicit/enum_with_selected_value/location_of_root_relief_evaluation.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""
from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private.gears.micro_geometry import _586
from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import List, Type, Any, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LocationOfRootReliefEvaluation")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LocationOfRootReliefEvaluation",)


class EnumWithSelectedValue_LocationOfRootReliefEvaluation(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LocationOfRootReliefEvaluation

    A specific implementation of 'EnumWithSelectedValue' for 'LocationOfRootReliefEvaluation' types.
    """

    __qualname__ = "LocationOfRootReliefEvaluation"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "_586.LocationOfRootReliefEvaluation":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _586.LocationOfRootReliefEvaluation
        """
        return _586.LocationOfRootReliefEvaluation

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _586.LocationOfRootReliefEvaluation.type_()

    @property
    def selected_value(self: "Self") -> "_586.LocationOfRootReliefEvaluation":
        """mastapy._private.gears.micro_geometry.LocationOfRootReliefEvaluation

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_586.LocationOfRootReliefEvaluation]":
        """List[mastapy._private.gears.micro_geometry.LocationOfRootReliefEvaluation]

        Note:
            This property is readonly.
        """
        return None

==> mastapy-14.1.3.tar.gz: mastapy-14.1.3/mastapy/_private/_internal/implicit/enum_with_selected_value/location_of_root_relief_evaluation.py <==
"""Implementations of 'EnumWithSelectedValue' in Python.

As Python does not have an implicit operator, this is the next
best solution for implementing these types properly.
"""

from __future__ import annotations

from enum import Enum
from typing import TYPE_CHECKING

from mastapy._private._internal import mixins
from mastapy._private._internal.python_net import python_net_import
from mastapy._private.gears.micro_geometry import _594

_ARRAY = python_net_import("System", "Array")
_ENUM_WITH_SELECTED_VALUE = python_net_import(
    "SMT.MastaAPI.Utility.Property", "EnumWithSelectedValue"
)

if TYPE_CHECKING:
    from typing import Any, List, Type, TypeVar

    Self = TypeVar("Self", bound="EnumWithSelectedValue_LocationOfRootReliefEvaluation")


__docformat__ = "restructuredtext en"
__all__ = ("EnumWithSelectedValue_LocationOfRootReliefEvaluation",)


class EnumWithSelectedValue_LocationOfRootReliefEvaluation(
    mixins.EnumWithSelectedValueMixin, Enum
):
    """EnumWithSelectedValue_LocationOfRootReliefEvaluation

    A specific implementation of 'EnumWithSelectedValue' for 'LocationOfRootReliefEvaluation' types.
    """

    __qualname__ = "LocationOfRootReliefEvaluation"

    @classmethod
    def wrapper_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "Any":
        """Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _ENUM_WITH_SELECTED_VALUE

    @classmethod
    def wrapped_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "_594.LocationOfRootReliefEvaluation":
        """Wrapped Pythonnet type of this class.

        Note:
            This property is readonly

        Returns:
            _594.LocationOfRootReliefEvaluation
        """
        return _594.LocationOfRootReliefEvaluation

    @classmethod
    def implicit_type(
        cls: "Type[EnumWithSelectedValue_LocationOfRootReliefEvaluation]",
    ) -> "Any":
        """Implicit Pythonnet type of this class.

        Note:
            This property is readonly.

        Returns:
            Any
        """
        return _594.LocationOfRootReliefEvaluation.type_()

    @property
    def selected_value(self: "Self") -> "_594.LocationOfRootReliefEvaluation":
        """mastapy.gears.micro_geometry.LocationOfRootReliefEvaluation

        Note:
            This property is readonly.
        """
        return None

    @property
    def available_values(self: "Self") -> "List[_594.LocationOfRootReliefEvaluation]":
        """List[mastapy.gears.micro_geometry.LocationOfRootReliefEvaluation]

        Note:
            This property is readonly.
        """
        return None
